@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -14,30 +14,30 @@
 
 import logging
 import math
+import warnings
 from copy import deepcopy
-from typing import Optional, Dict, Union, List, cast
+from typing import Dict, List, Optional, Union, cast
 
 import numpy as np
-
 from qiskit import QuantumCircuit, QuantumRegister
 from qiskit.algorithms import AmplificationProblem
-from qiskit.utils import QuantumInstance, algorithm_globals
 from qiskit.algorithms.amplitude_amplifiers.grover import Grover
 from qiskit.circuit.library import QuadraticForm
-from qiskit.providers import Backend, BaseBackend
+from qiskit.primitives import BaseSampler
+from qiskit.providers import Backend
 from qiskit.quantum_info import partial_trace
-from .optimization_algorithm import (
-    OptimizationResultStatus,
-    OptimizationAlgorithm,
-    OptimizationResult,
-    SolutionSample,
-)
-from ..converters.quadratic_program_to_qubo import (
-    QuadraticProgramToQubo,
-    QuadraticProgramConverter,
-)
+from qiskit.utils import QuantumInstance, algorithm_globals
+
+from ..converters.quadratic_program_to_qubo import QuadraticProgramConverter, QuadraticProgramToQubo
+from ..exceptions import QiskitOptimizationError
 from ..problems import Variable
 from ..problems.quadratic_program import QuadraticProgram
+from .optimization_algorithm import (
+    OptimizationAlgorithm,
+    OptimizationResult,
+    OptimizationResultStatus,
+    SolutionSample,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -49,11 +49,12 @@ class GroverOptimizer(OptimizationAlgorithm):
         self,
         num_value_qubits: int,
         num_iterations: int = 3,
-        quantum_instance: Optional[Union[BaseBackend, Backend, QuantumInstance]] = None,
+        quantum_instance: Optional[Union[Backend, QuantumInstance]] = None,
         converters: Optional[
             Union[QuadraticProgramConverter, List[QuadraticProgramConverter]]
         ] = None,
         penalty: Optional[float] = None,
+        sampler: Optional[BaseSampler] = None,
     ) -> None:
         """
         Args:
@@ -66,21 +67,36 @@ class GroverOptimizer(OptimizationAlgorithm):
                 :class:`~qiskit_optimization.converters.QuadraticProgramToQubo` will be used.
             penalty: The penalty factor used in the default
                 :class:`~qiskit_optimization.converters.QuadraticProgramToQubo` converter
+            sampler: A Sampler to use for sampling the results of the circuits.
 
         Raises:
+            ValueError: If both a quantum instance and sampler are set.
             TypeError: When there one of converters is an invalid type.
         """
         self._num_value_qubits = num_value_qubits
         self._num_key_qubits = 0
         self._n_iterations = num_iterations
-        self._quantum_instance = None  # type: Optional[QuantumInstance]
         self._circuit_results = {}  # type: dict
-
-        if quantum_instance is not None:
-            self.quantum_instance = quantum_instance
-
         self._converters = self._prepare_converters(converters, penalty)
 
+        if quantum_instance is not None and sampler is not None:
+            raise ValueError("Only one of quantum_instance or sampler can be passed, not both!")
+
+        self._quantum_instance = None  # type: Optional[QuantumInstance]
+        if quantum_instance is not None:
+            warnings.warn(
+                "The quantum_instance argument has been superseded by the sampler argument. "
+                "This argument will be deprecated in a future release and subsequently "
+                "removed after that.",
+                category=PendingDeprecationWarning,
+                stacklevel=2,
+            )
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore", category=PendingDeprecationWarning)
+                self.quantum_instance = quantum_instance
+
+        self._sampler = sampler
+
     @property
     def quantum_instance(self) -> QuantumInstance:
         """The quantum instance to run the circuits.
@@ -88,18 +104,30 @@ class GroverOptimizer(OptimizationAlgorithm):
         Returns:
             The quantum instance used in the algorithm.
         """
+        warnings.warn(
+            "The quantum_instance argument has been superseded by the sampler argument. "
+            "This argument will be deprecated in a future release and subsequently "
+            "removed after that.",
+            category=PendingDeprecationWarning,
+            stacklevel=2,
+        )
         return self._quantum_instance
 
     @quantum_instance.setter
-    def quantum_instance(
-        self, quantum_instance: Union[Backend, BaseBackend, QuantumInstance]
-    ) -> None:
+    def quantum_instance(self, quantum_instance: Union[Backend, QuantumInstance]) -> None:
         """Set the quantum instance used to run the circuits.
 
         Args:
             quantum_instance: The quantum instance to be used in the algorithm.
         """
-        if isinstance(quantum_instance, (BaseBackend, Backend)):
+        warnings.warn(
+            "The GroverOptimizer.quantum_instance setter is pending deprecation. "
+            "This property will be deprecated in a future release and subsequently "
+            "removed after that.",
+            category=PendingDeprecationWarning,
+            stacklevel=2,
+        )
+        if isinstance(quantum_instance, Backend):
             self._quantum_instance = QuantumInstance(quantum_instance)
         else:
             self._quantum_instance = quantum_instance
@@ -164,11 +192,16 @@ class GroverOptimizer(OptimizationAlgorithm):
             The result of the optimizer applied to the problem.
 
         Raises:
+            ValueError: If a quantum instance or a sampler has not been provided.
+            ValueError: If both a quantum instance and sampler are set.
             AttributeError: If the quantum instance has not been set.
             QiskitOptimizationError: If the problem is incompatible with the optimizer.
         """
-        if self.quantum_instance is None:
-            raise AttributeError("The quantum instance or backend has not been set.")
+        if self._sampler is None and self._quantum_instance is None:
+            raise ValueError("A quantum instance or sampler must be provided.")
+
+        if self._quantum_instance is not None and self._sampler is not None:
+            raise ValueError("Only one of quantum_instance or sampler can be passed, not both!")
 
         self._verify_compatibility(problem)
 
@@ -187,7 +220,7 @@ class GroverOptimizer(OptimizationAlgorithm):
         n_value = self._num_value_qubits
 
         # Variables for tracking the solutions encountered.
-        num_solutions = 2 ** n_key
+        num_solutions = 2**n_key
         keys_measured = []
 
         # Variables for result object.
@@ -201,7 +234,7 @@ class GroverOptimizer(OptimizationAlgorithm):
         # Initialize oracle helper object.
         qr_key_value = QuantumRegister(self._num_key_qubits + self._num_value_qubits)
         orig_constant = problem_.objective.constant
-        measurement = not self.quantum_instance.is_statevector
+        measurement = self._quantum_instance is None or not self._quantum_instance.is_statevector
         oracle, is_good_state = self._get_oracle(qr_key_value)
 
         while not optimum_found:
@@ -248,15 +281,19 @@ class GroverOptimizer(OptimizationAlgorithm):
                     threshold = optimum_value
 
                     # trace out work qubits and store samples
-                    if self._quantum_instance.is_statevector:
-                        indices = list(range(n_key, len(outcome)))
-                        rho = partial_trace(self._circuit_results, indices)
-                        self._circuit_results = np.diag(rho.data) ** 0.5
-                    else:
+                    if self._sampler is not None:
                         self._circuit_results = {
                             i[-1 * n_key :]: v for i, v in self._circuit_results.items()
                         }
-
+                    else:
+                        if self._quantum_instance.is_statevector:
+                            indices = list(range(n_key, len(outcome)))
+                            rho = partial_trace(self._circuit_results, indices)
+                            self._circuit_results = cast(Dict, np.diag(rho.data) ** 0.5)
+                        else:
+                            self._circuit_results = {
+                                i[-1 * n_key :]: v for i, v in self._circuit_results.items()
+                            }
                     raw_samples = self._eigenvector_to_solutions(
                         self._circuit_results, problem_init
                     )
@@ -290,7 +327,7 @@ class GroverOptimizer(OptimizationAlgorithm):
         if optimum_value >= 0 and orig_constant == 0:
             optimum_key = 0
 
-        opt_x = np.array([1 if s == "1" else 0 for s in ("{0:%sb}" % n_key).format(optimum_key)])
+        opt_x = np.array([1 if s == "1" else 0 for s in f"{optimum_key:{n_key}b}"])
         # Compute function value of minimization QUBO
         fval = problem_init.objective.evaluate(opt_x)
 
@@ -314,37 +351,58 @@ class GroverOptimizer(OptimizationAlgorithm):
 
     def _measure(self, circuit: QuantumCircuit) -> str:
         """Get probabilities from the given backend, and picks a random outcome."""
-        probs = self._get_probs(circuit)
+        probs = self._get_prob_dist(circuit)
         logger.info("Frequencies: %s", probs)
         # Pick a random outcome.
         return algorithm_globals.random.choice(list(probs.keys()), 1, p=list(probs.values()))[0]
 
-    def _get_probs(self, qc: QuantumCircuit) -> Dict[str, float]:
+    def _get_prob_dist(self, qc: QuantumCircuit) -> Dict[str, float]:
         """Gets probabilities from a given backend."""
         # Execute job and filter results.
-        result = self.quantum_instance.execute(qc)
-        if self.quantum_instance.is_statevector:
-            state = result.get_statevector(qc)
-            keys = [
-                bin(i)[2::].rjust(int(np.log2(len(state))), "0")[::-1] for i in range(0, len(state))
-            ]
-            probs = [abs(a) ** 2 for a in state]
-            total = math.fsum(probs)
-            probs = [p / total for p in probs]
-            hist = {key: prob for key, prob in zip(keys, probs) if prob > 0}
-            self._circuit_results = state
+        if self._sampler is not None:
+            job = self._sampler.run([qc])
+
+            try:
+                result = job.result()
+            except Exception as exc:
+                raise QiskitOptimizationError("Sampler job failed.") from exc
+            quasi_dist = result.quasi_dists[0]
+            raw_prob_dist = {
+                k: v
+                for k, v in quasi_dist.binary_probabilities(qc.num_qubits).items()
+                if v >= self._MIN_PROBABILITY
+            }
+            prob_dist = {k[::-1]: v for k, v in raw_prob_dist.items()}
+            self._circuit_results = {i: v**0.5 for i, v in raw_prob_dist.items()}
         else:
-            state = result.get_counts(qc)
-            shots = self.quantum_instance.run_config.shots
-            hist = {key[::-1]: val / shots for key, val in sorted(state.items()) if val > 0}
-            self._circuit_results = {b: (v / shots) ** 0.5 for (b, v) in state.items()}
-        return hist
+            result = self._quantum_instance.execute(qc)
+            if self._quantum_instance.is_statevector:
+                state = result.get_statevector(qc)
+                if not isinstance(state, np.ndarray):
+                    state = state.data
+                keys = [
+                    bin(i)[2::].rjust(int(np.log2(len(state))), "0")[::-1]
+                    for i in range(0, len(state))
+                ]
+                probs = [abs(a) ** 2 for a in state]
+                total = math.fsum(probs)
+                probs = [p / total for p in probs]
+                prob_dist = {key: prob for key, prob in zip(keys, probs) if prob > 0}
+                self._circuit_results = state
+            else:
+                state = result.get_counts(qc)
+                shots = self._quantum_instance.run_config.shots
+                prob_dist = {
+                    key[::-1]: val / shots for key, val in sorted(state.items()) if val > 0
+                }
+                self._circuit_results = {b: (v / shots) ** 0.5 for (b, v) in state.items()}
+        return prob_dist
 
     @staticmethod
     def _bin_to_int(v: str, num_value_bits: int) -> int:
         """Converts a binary string of n bits using two's complement to an integer."""
         if v.startswith("1"):
-            int_v = int(v, 2) - 2 ** num_value_bits
+            int_v = int(v, 2) - 2**num_value_bits
         else:
             int_v = int(v, 2)
 
