@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2018, 2021.
+# (C) Copyright IBM 2018, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -17,17 +17,11 @@ from typing import Union, Optional, Dict, List
 
 import networkx as nx
 import numpy as np
-from qiskit.exceptions import MissingOptionalLibraryError
 
-from qiskit_optimization.algorithms import OptimizationResult
+import qiskit_optimization.optionals as _optionals
 from .optimization_application import OptimizationApplication
-
-try:
-    import matplotlib as _
-
-    _HAS_MATPLOTLIB = True
-except ImportError:
-    _HAS_MATPLOTLIB = False
+from ..algorithms import OptimizationResult
+from ..deprecation import DeprecatedType, deprecate_method
 
 
 class GraphOptimizationApplication(OptimizationApplication):
@@ -39,11 +33,13 @@ class GraphOptimizationApplication(OptimizationApplication):
         """
         Args:
             graph: A graph representing a problem. It can be specified directly as a
-            NetworkX Graph, or as an array or list if format suitable to build out a NetworkX graph.
+                `NetworkX <https://networkx.org/>`_ graph,
+                or as an array or list format suitable to build out a NetworkX graph.
         """
         # The view of the graph is stored which means the graph can not be changed.
         self._graph = nx.Graph(graph).copy(as_view=True)
 
+    @_optionals.HAS_MATPLOTLIB.require_in_call
     def draw(
         self,
         result: Optional[Union[OptimizationResult, np.ndarray]] = None,
@@ -55,16 +51,7 @@ class GraphOptimizationApplication(OptimizationApplication):
         Args:
             result: The calculated result for the problem
             pos: The positions of nodes
-        Raises:
-            MissingOptionalLibraryError: if matplotlib is not installed.
         """
-        if not _HAS_MATPLOTLIB:
-            raise MissingOptionalLibraryError(
-                libname="matplotlib",
-                name="GraphOptimizationApplication",
-                pip_install="pip install 'qiskit-optimization[matplotlib]'",
-            )
-
         if result is None:
             nx.draw(self._graph, pos=pos, with_labels=True)
         else:
@@ -94,9 +81,11 @@ class GraphOptimizationApplication(OptimizationApplication):
         return self._graph
 
     @staticmethod
+    @deprecate_method(
+        "0.3.0", DeprecatedType.FUNCTION, "networkx.gnm_random_graph", "in NetworkX, directly"
+    )
     def random_graph(num_nodes: int, num_edges: int, seed: Optional[int] = None) -> nx.Graph:
         """
-
         Args:
             num_nodes: The number of nodes in a graph
             num_edges: The number of edges in a graph
@@ -105,5 +94,4 @@ class GraphOptimizationApplication(OptimizationApplication):
         Returns:
             A random graph of NetworkX
         """
-        graph = nx.gnm_random_graph(num_nodes, num_edges, seed)
-        return graph
+        return nx.gnm_random_graph(num_nodes, num_edges, seed)
