@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2018, 2021.
+# (C) Copyright IBM 2018, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -11,13 +11,15 @@
 # that they have been altered from the originals.
 
 """An abstract class for optimization application classes."""
-from typing import Union, Dict
-from collections import OrderedDict
 from abc import ABC, abstractmethod
+from collections import OrderedDict
+from typing import Dict, Union
 
 import numpy as np
-
 from qiskit.opflow import StateFn
+from qiskit.quantum_info import Statevector
+from qiskit.result import QuasiDistribution
+
 from qiskit_optimization.algorithms import OptimizationResult
 from qiskit_optimization.problems.quadratic_program import QuadraticProgram
 
@@ -54,30 +56,50 @@ class OptimizationApplication(ABC):
         else:
             raise TypeError(
                 "Unsupported format of result. Provide an　OptimizationResult or a",
-                "binary array using np.ndarray instead of {}".format(type(result)),
+                f" binary array using np.ndarray instead of {type(result)}",
             )
         return x
 
     @staticmethod
-    def sample_most_likely(state_vector: Union[np.ndarray, Dict]) -> np.ndarray:
+    def sample_most_likely(
+        state_vector: Union[QuasiDistribution, Statevector, np.ndarray, Dict]
+    ) -> np.ndarray:
         """Compute the most likely binary string from state vector.
 
         Args:
-            state_vector: state vector or counts.
+            state_vector: state vector or counts or quasi-probabilities.
 
         Returns:
             binary string as numpy.ndarray of ints.
+
+        Raises:
+            ValueError: if state_vector is not QuasiDistribution, Statevector,
+                np.ndarray, or dict.
         """
-        if isinstance(state_vector, (OrderedDict, dict)):
+        if isinstance(state_vector, QuasiDistribution):
+            probabilities = state_vector.binary_probabilities()
+            binary_string = max(probabilities.items(), key=lambda kv: kv[1])[0]
+            x = np.asarray([int(y) for y in reversed(list(binary_string))])
+            return x
+        elif isinstance(state_vector, Statevector):
+            probabilities = state_vector.probabilities()
+            n = state_vector.num_qubits
+            k = np.argmax(np.abs(probabilities))
+            x = np.zeros(n)
+            for i in range(n):
+                x[i] = k % 2
+                k >>= 1
+            return x
+        elif isinstance(state_vector, (OrderedDict, dict)):
             # get the binary string with the largest count
-            binary_string = sorted(state_vector.items(), key=lambda kv: kv[1])[-1][0]
+            binary_string = max(state_vector.items(), key=lambda kv: kv[1])[0]
             x = np.asarray([int(y) for y in reversed(list(binary_string))])
             return x
         elif isinstance(state_vector, StateFn):
             binary_string = list(state_vector.sample().keys())[0]
             x = np.asarray([int(y) for y in reversed(list(binary_string))])
             return x
-        else:
+        elif isinstance(state_vector, np.ndarray):
             n = int(np.log2(state_vector.shape[0]))
             k = np.argmax(np.abs(state_vector))
             x = np.zeros(n)
@@ -85,3 +107,8 @@ class OptimizationApplication(ABC):
                 x[i] = k % 2
                 k >>= 1
             return x
+        else:
+            raise ValueError(
+                "state vector should be QuasiDistribution, Statevector, ndarray, or dict. "
+                f"But it is {type(state_vector)}."
+            )
