@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2019, 2021.
+# (C) Copyright IBM 2019, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -79,3 +79,17 @@ class LinearConstraint(Constraint):
             The left-hand-side of the constraint given the variable values.
         """
         return self.linear.evaluate(x)
+
+    def __repr__(self):
+        # pylint: disable=cyclic-import
+        from ..translators.prettyprint import expr2str, DEFAULT_TRUNCATE
+
+        lhs = expr2str(linear=self.linear, truncate=DEFAULT_TRUNCATE)
+        return f"<{self.__class__.__name__}: {lhs} {self.sense.label} {self.rhs} '{self.name}'>"
+
+    def __str__(self):
+        # pylint: disable=cyclic-import
+        from ..translators.prettyprint import expr2str
+
+        lhs = expr2str(linear=self.linear)
+        return f"{lhs} {self.sense.label} {self.rhs} '{self.name}'"
