@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2019, 2021.
+# (C) Copyright IBM 2019, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -200,3 +200,17 @@ class QuadraticObjective(QuadraticProgramElement):
                 "Need to define the objective function after defining all variables"
             )
         return self.linear.evaluate_gradient(x) + self.quadratic.evaluate_gradient(x)
+
+    def __repr__(self):
+        # pylint: disable=cyclic-import
+        from ..translators.prettyprint import expr2str, DEFAULT_TRUNCATE
+
+        expr_str = expr2str(self.constant, self.linear, self.quadratic, DEFAULT_TRUNCATE)
+        return f"<{self.__class__.__name__}: {self._sense.name.lower()} {expr_str}>"
+
+    def __str__(self):
+        # pylint: disable=cyclic-import
+        from ..translators.prettyprint import expr2str
+
+        expr_str = expr2str(self.constant, self.linear, self.quadratic)
+        return f"{self._sense.name.lower()} {expr_str}"
