@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2021.
+# (C) Copyright IBM 2021, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -17,7 +17,7 @@ Quadratic program translators (:mod:`qiskit_optimization.translators`)
 .. currentmodule:: qiskit_optimization.translators
 
 Translators between :class:`~qiskit_optimization.problems.QuadraticProgram` and
-other optimization models.
+other optimization models or other objects.
 
 Translators
 ======================
@@ -37,7 +37,7 @@ from .docplex_mp import from_docplex_mp, to_docplex_mp
 from .gurobipy import from_gurobipy, to_gurobipy
 from .ising import from_ising, to_ising
 
-_all = [
+__all__ = [
     "from_docplex_mp",
     "to_docplex_mp",
     "from_gurobipy",
