@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2018, 2021.
+# (C) Copyright IBM 2018, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -12,6 +12,6 @@
 
 """ Optimization test packages """
 
-from .optimization_test_case import QiskitOptimizationTestCase, requires_extra_library
+from .optimization_test_case import QiskitOptimizationTestCase
 
-__all__ = ["QiskitOptimizationTestCase", "requires_extra_library"]
+__all__ = ["QiskitOptimizationTestCase"]
