@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2018, 2021.
+# (C) Copyright IBM 2018, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -10,32 +10,28 @@
 # copyright notice, and modified files need to carry a notice indicating
 # that they have been altered from the originals.
 
-""" Test Min Eigen Optimizer """
+""" Test Min Eigen Optimizer with the primitive-based minimum eigensolver """
 
 import unittest
-from test.optimization_test_case import (
-    QiskitOptimizationTestCase,
-    requires_extra_library,
-)
-from test.runtime.fake_vqeruntime import FakeRuntimeProvider
+from test.optimization_test_case import QiskitOptimizationTestCase
+from test.runtime.fake_vqeruntime import FakeQAOARuntimeProvider, FakeVQERuntimeProvider
 
 import numpy as np
-from ddt import data, ddt
-from docplex.mp.model import Model
-from qiskit import BasicAer
-from qiskit.algorithms import QAOA, VQE, NumPyMinimumEigensolver
+from ddt import data, ddt, unpack
+from qiskit.algorithms.minimum_eigensolvers import QAOA, NumPyMinimumEigensolver, SamplingVQE, VQE
 from qiskit.algorithms.optimizers import COBYLA, SPSA
 from qiskit.circuit.library import TwoLocal
+from qiskit.primitives import Estimator, Sampler
 from qiskit.providers.basicaer import QasmSimulatorPy
-from qiskit.utils import QuantumInstance, algorithm_globals
+from qiskit.utils import algorithm_globals
+
+import qiskit_optimization.optionals as _optionals
 from qiskit_optimization.algorithms import (
     CplexOptimizer,
-    MinimumEigenOptimizer,
     MinimumEigenOptimizationResult,
+    MinimumEigenOptimizer,
 )
-from qiskit_optimization.algorithms.optimization_algorithm import (
-    OptimizationResultStatus,
-)
+from qiskit_optimization.algorithms.optimization_algorithm import OptimizationResultStatus
 from qiskit_optimization.converters import (
     InequalityToEquality,
     IntegerToBinary,
@@ -44,8 +40,7 @@ from qiskit_optimization.converters import (
     QuadraticProgramToQubo,
 )
 from qiskit_optimization.problems import QuadraticProgram
-from qiskit_optimization.runtime import VQEProgram, QAOAProgram
-from qiskit_optimization.translators import from_docplex_mp
+from qiskit_optimization.runtime import QAOAClient, VQEClient
 
 
 @ddt
@@ -55,26 +50,14 @@ class TestMinEigenOptimizer(QiskitOptimizationTestCase):
     def setUp(self):
         super().setUp()
 
+        self._seed = 123
+
         # setup minimum eigen solvers
-        self.min_eigen_solvers = {}
+        self.min_eigen_solvers = {
+            "exact": NumPyMinimumEigensolver(),
+            "qaoa": QAOA(sampler=Sampler(), optimizer=COBYLA()),
+        }
 
-        # exact eigen solver
-        self.min_eigen_solvers["exact"] = NumPyMinimumEigensolver()
-
-        # QAOA
-        optimizer = COBYLA()
-        self.min_eigen_solvers["qaoa"] = QAOA(optimizer=optimizer)
-        # simulators
-        self.sv_simulator = QuantumInstance(
-            BasicAer.get_backend("statevector_simulator"),
-            seed_simulator=123,
-            seed_transpiler=123,
-        )
-        self.qasm_simulator = QuantumInstance(
-            BasicAer.get_backend("qasm_simulator"),
-            seed_simulator=123,
-            seed_transpiler=123,
-        )
         # test minimize
         self.op_minimize = QuadraticProgram()
         self.op_minimize.integer_var(0, 3, "x")
@@ -90,28 +73,26 @@ class TestMinEigenOptimizer(QiskitOptimizationTestCase):
         self.op_maximize.linear_constraint(linear={"x": 1, "y": 1}, sense="<=", rhs=1, name="xy")
 
         # test bit ordering
-        mdl = Model("docplex model")
-        x = mdl.binary_var("x")
-        y = mdl.binary_var("y")
-        mdl.minimize(x - 2 * y)
-        self.op_ordering = from_docplex_mp(mdl)
+        self.op_ordering = QuadraticProgram("bit ordering")
+        self.op_ordering.binary_var("x")
+        self.op_ordering.binary_var("y")
+        self.op_ordering.minimize(linear={"x": 1, "y": -2})
 
     @data(
         ("exact", None, "op_ip1.lp"),
-        ("qaoa", "statevector_simulator", "op_ip1.lp"),
-        ("qaoa", "qasm_simulator", "op_ip1.lp"),
+        ("qaoa", None, "op_ip1.lp"),
+        ("qaoa", 10000, "op_ip1.lp"),
     )
-    @requires_extra_library
-    def test_min_eigen_optimizer(self, config):
+    @unpack
+    @unittest.skipIf(not _optionals.HAS_CPLEX, "CPLEX not available.")
+    def test_min_eigen_optimizer(self, min_eigen_solver_name, shots, filename):
         """Min Eigen Optimizer Test"""
         try:
-            # unpack configuration
-            min_eigen_solver_name, backend, filename = config
-
             # get minimum eigen solver
             min_eigen_solver = self.min_eigen_solvers[min_eigen_solver_name]
-            if backend:
-                min_eigen_solver.quantum_instance = BasicAer.get_backend(backend)
+            if min_eigen_solver_name == "qaoa":
+                min_eigen_solver.sampler.options.shots = shots
+                min_eigen_solver.sampler.options.seed = self._seed
 
             # construct minimum eigen optimizer
             min_eigen_optimizer = MinimumEigenOptimizer(min_eigen_solver)
@@ -141,13 +122,11 @@ class TestMinEigenOptimizer(QiskitOptimizationTestCase):
         ("op_ip1.lp", -470, 12, OptimizationResultStatus.SUCCESS),
         ("op_ip1.lp", np.inf, None, OptimizationResultStatus.FAILURE),
     )
-    @requires_extra_library
-    def test_min_eigen_optimizer_with_filter(self, config):
+    @unpack
+    @unittest.skipIf(not _optionals.HAS_CPLEX, "CPLEX not available.")
+    def test_min_eigen_optimizer_with_filter(self, filename, lowerbound, fval, status):
         """Min Eigen Optimizer Test"""
         try:
-            # unpack configuration
-            filename, lowerbound, fval, status = config
-
             # get minimum eigen solver
             min_eigen_solver = NumPyMinimumEigensolver()
 
@@ -245,19 +224,16 @@ class TestMinEigenOptimizer(QiskitOptimizationTestCase):
         self.assertAlmostEqual(result.raw_samples[0].probability, 1.0)
         self.assertEqual(result.raw_samples[0].status, success)
 
-    @data("sv", "qasm")
-    def test_samples_qaoa(self, simulator):
+    def test_samples_qaoa(self):
         """Test samples for QAOA"""
         # test minimize
         algorithm_globals.random_seed = 4
-        quantum_instance = self.sv_simulator if simulator == "sv" else self.qasm_simulator
-        qaoa = QAOA(quantum_instance=quantum_instance, reps=2)
+        sampler = Sampler()
+        qaoa = QAOA(sampler=sampler, optimizer=COBYLA(), reps=2)
         min_eigen_optimizer = MinimumEigenOptimizer(qaoa)
         result = min_eigen_optimizer.solve(self.op_minimize)
         success = OptimizationResultStatus.SUCCESS
         opt_sol = 1
-        self.assertEqual(len(result.samples), 8)
-        self.assertEqual(len(result.raw_samples), 32)
         self.assertAlmostEqual(sum(s.probability for s in result.samples), 1)
         self.assertAlmostEqual(sum(s.probability for s in result.raw_samples), 1)
         self.assertAlmostEqual(min(s.fval for s in result.samples), 0)
@@ -275,11 +251,9 @@ class TestMinEigenOptimizer(QiskitOptimizationTestCase):
         self.assertEqual(result.raw_samples[0].status, success)
         # test maximize
         opt_sol = 2
-        qaoa = QAOA(quantum_instance=quantum_instance, reps=2)
+        qaoa = QAOA(sampler=sampler, optimizer=COBYLA(), reps=2)
         min_eigen_optimizer = MinimumEigenOptimizer(qaoa)
         result = min_eigen_optimizer.solve(self.op_maximize)
-        self.assertEqual(len(result.samples), 8)
-        self.assertEqual(len(result.raw_samples), 16)
         self.assertAlmostEqual(sum(s.probability for s in result.samples), 1)
         self.assertAlmostEqual(sum(s.probability for s in result.raw_samples), 1)
         self.assertAlmostEqual(max(s.fval for s in result.samples), 5)
@@ -305,7 +279,7 @@ class TestMinEigenOptimizer(QiskitOptimizationTestCase):
         self.assertEqual(result.raw_samples[0].status, success)
         # test bit ordering
         opt_sol = -2
-        qaoa = QAOA(quantum_instance=quantum_instance, reps=2)
+        qaoa = QAOA(sampler=sampler, optimizer=COBYLA(), reps=2)
         min_eigen_optimizer = MinimumEigenOptimizer(qaoa)
         result = min_eigen_optimizer.solve(self.op_ordering)
         self.assertEqual(result.fval, opt_sol)
@@ -327,17 +301,16 @@ class TestMinEigenOptimizer(QiskitOptimizationTestCase):
         self.assertAlmostEqual(result.raw_samples[0].fval, opt_sol)
         self.assertEqual(result.raw_samples[0].status, success)
 
-    @data("sv", "qasm")
-    def test_samples_vqe(self, simulator):
+    def test_samples_vqe(self):
         """Test samples for VQE"""
         # test minimize
         algorithm_globals.random_seed = 1
-        quantum_instance = self.sv_simulator if simulator == "sv" else self.qasm_simulator
         opt_sol = -2
         success = OptimizationResultStatus.SUCCESS
         optimizer = SPSA(maxiter=100)
         ry_ansatz = TwoLocal(5, "ry", "cz", reps=3, entanglement="full")
-        vqe_mes = VQE(ry_ansatz, optimizer=optimizer, quantum_instance=quantum_instance)
+        sampler = Sampler()
+        vqe_mes = SamplingVQE(sampler, ry_ansatz, optimizer=optimizer)
         vqe = MinimumEigenOptimizer(vqe_mes)
         results = vqe.solve(self.op_ordering)
         self.assertEqual(results.fval, opt_sol)
@@ -359,32 +332,40 @@ class TestMinEigenOptimizer(QiskitOptimizationTestCase):
         self.assertAlmostEqual(results.raw_samples[0].fval, opt_sol)
         self.assertEqual(results.raw_samples[0].status, success)
 
+    def test_errors(self):
+        """Test for errors"""
+        optimizer = SPSA(maxiter=100)
+        ry_ansatz = TwoLocal(5, "ry", "cz", reps=3, entanglement="full")
+        estimator = Estimator()
+        vqe = VQE(estimator, ry_ansatz, optimizer)
+        with self.assertRaises(TypeError):
+            _ = MinimumEigenOptimizer(vqe)
+
     @data("vqe", "qaoa")
     def test_runtime(self, subroutine):
         """Test vqe and qaoa runtime"""
         optimizer = {"name": "SPSA", "maxiter": 100}
         backend = QasmSimulatorPy()
-        provider = FakeRuntimeProvider()
 
         if subroutine == "vqe":
             ry_ansatz = TwoLocal(5, "ry", "cz", reps=3, entanglement="full")
             initial_point = np.random.default_rng(42).random(ry_ansatz.num_parameters)
-            solver = VQEProgram(
+            solver = VQEClient(
                 ansatz=ry_ansatz,
                 optimizer=optimizer,
                 initial_point=initial_point,
                 backend=backend,
-                provider=provider,
+                provider=FakeVQERuntimeProvider(),
             )
         else:
             reps = 2
             initial_point = np.random.default_rng(42).random(2 * reps)
-            solver = QAOAProgram(
+            solver = QAOAClient(
                 optimizer=optimizer,
                 reps=reps,
                 initial_point=initial_point,
                 backend=backend,
-                provider=provider,
+                provider=FakeQAOARuntimeProvider(),
             )
 
         opt = MinimumEigenOptimizer(solver)
