@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2021.
+# (C) Copyright IBM 2021, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -10,19 +10,20 @@
 # copyright notice, and modified files need to carry a notice indicating
 # that they have been altered from the originals.
 
-""" Test warm start QAOA optimizer. """
-from test import QiskitOptimizationTestCase, requires_extra_library
+""" Test warm start QAOA optimizer with the primitive-based minimum eigensolver. """
+
+import unittest
+from test import QiskitOptimizationTestCase
 
 import numpy as np
-
 from docplex.mp.model import Model
-from qiskit import BasicAer
-from qiskit.algorithms import QAOA
+from qiskit.algorithms.minimum_eigensolvers import QAOA
+from qiskit.algorithms.optimizers import SLSQP
+from qiskit.primitives.sampler import Sampler
 
+import qiskit_optimization.optionals as _optionals
 from qiskit_optimization.algorithms import SlsqpOptimizer
-from qiskit_optimization.algorithms.goemans_williamson_optimizer import (
-    GoemansWilliamsonOptimizer,
-)
+from qiskit_optimization.algorithms.goemans_williamson_optimizer import GoemansWilliamsonOptimizer
 from qiskit_optimization.algorithms.warm_start_qaoa_optimizer import (
     MeanAggregator,
     WarmStartQAOAOptimizer,
@@ -34,7 +35,7 @@ from qiskit_optimization.translators import from_docplex_mp
 class TestWarmStartQAOAOptimizer(QiskitOptimizationTestCase):
     """Tests for the warm start QAOA optimizer."""
 
-    @requires_extra_library
+    @unittest.skipIf(not _optionals.HAS_CVXPY, "CVXPY not available.")
     def test_max_cut(self):
         """Basic test on the max cut problem."""
         graph = np.array(
@@ -49,8 +50,7 @@ class TestWarmStartQAOAOptimizer(QiskitOptimizationTestCase):
         presolver = GoemansWilliamsonOptimizer(num_cuts=10)
         problem = Maxcut(graph).to_quadratic_program()
 
-        backend = BasicAer.get_backend("statevector_simulator")
-        qaoa = QAOA(quantum_instance=backend, reps=1)
+        qaoa = QAOA(sampler=Sampler(), optimizer=SLSQP(), reps=1)
         aggregator = MeanAggregator()
         optimizer = WarmStartQAOAOptimizer(
             pre_solver=presolver,
@@ -82,8 +82,7 @@ class TestWarmStartQAOAOptimizer(QiskitOptimizationTestCase):
 
         problem = from_docplex_mp(model)
 
-        backend = BasicAer.get_backend("statevector_simulator")
-        qaoa = QAOA(quantum_instance=backend, reps=1)
+        qaoa = QAOA(sampler=Sampler(), optimizer=SLSQP(), reps=1)
         aggregator = MeanAggregator()
         optimizer = WarmStartQAOAOptimizer(
             pre_solver=SlsqpOptimizer(),
@@ -110,8 +109,7 @@ class TestWarmStartQAOAOptimizer(QiskitOptimizationTestCase):
         model.minimize((u - v + 2) ** 2)
         problem = from_docplex_mp(model)
 
-        backend = BasicAer.get_backend("statevector_simulator")
-        qaoa = QAOA(quantum_instance=backend, reps=1)
+        qaoa = QAOA(sampler=Sampler(), optimizer=SLSQP(), reps=1)
         optimizer = WarmStartQAOAOptimizer(
             pre_solver=SlsqpOptimizer(),
             relax_for_pre_solver=True,
@@ -125,3 +123,7 @@ class TestWarmStartQAOAOptimizer(QiskitOptimizationTestCase):
         np.testing.assert_almost_equal([0, 1], result_warm.x, 3)
         self.assertIsNotNone(result_warm.fval)
         np.testing.assert_almost_equal(1, result_warm.fval, 3)
+
+
+if __name__ == "__main__":
+    unittest.main()
