@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -13,21 +13,16 @@
 """ Test Converters """
 
 import unittest
-from test.optimization_test_case import (
-    QiskitOptimizationTestCase,
-    requires_extra_library,
-)
+from test.optimization_test_case import QiskitOptimizationTestCase
 
 import numpy as np
 from docplex.mp.model import Model
-from qiskit.algorithms import NumPyMinimumEigensolver
-from qiskit.opflow import Z, I
-from qiskit_optimization import QuadraticProgram, QiskitOptimizationError
-from qiskit_optimization.algorithms import (
-    MinimumEigenOptimizer,
-    CplexOptimizer,
-    ADMMOptimizer,
-)
+from qiskit.algorithms.minimum_eigensolvers import NumPyMinimumEigensolver
+from qiskit.opflow import I, Z
+
+import qiskit_optimization.optionals as _optionals
+from qiskit_optimization import QiskitOptimizationError, QuadraticProgram
+from qiskit_optimization.algorithms import ADMMOptimizer, CplexOptimizer, MinimumEigenOptimizer
 from qiskit_optimization.algorithms.admm_optimizer import ADMMParameters
 from qiskit_optimization.converters import (
     InequalityToEquality,
@@ -38,7 +33,6 @@ from qiskit_optimization.converters import (
 from qiskit_optimization.problems import Constraint, Variable
 from qiskit_optimization.translators import from_docplex_mp
 
-
 QUBIT_OP_MAXIMIZE_SAMPLE = (
     -199999.5 * (I ^ I ^ I ^ Z)
     + -399999.5 * (I ^ I ^ Z ^ I)
@@ -88,7 +82,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test InequalityToEqualityConverter with binary variables"""
         op = QuadraticProgram()
         for i in range(3):
-            op.binary_var(name="x{}".format(i))
+            op.binary_var(name=f"x{i}")
         # Linear constraints
         linear_constraint = {"x0": 1, "x1": 1}
         op.linear_constraint(linear_constraint, Constraint.Sense.EQ, 1, "x0x1")
@@ -169,7 +163,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test InequalityToEqualityConverter with integer variables"""
         op = QuadraticProgram()
         for i in range(3):
-            op.integer_var(name="x{}".format(i), lowerbound=-3, upperbound=3)
+            op.integer_var(name=f"x{i}", lowerbound=-3, upperbound=3)
         # Linear constraints
         linear_constraint = {"x0": 1, "x1": 1}
         op.linear_constraint(linear_constraint, Constraint.Sense.EQ, 1, "x0x1")
@@ -246,7 +240,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test integer mode of InequalityToEqualityConverter()"""
         op = QuadraticProgram()
         for i in range(3):
-            op.binary_var(name="x{}".format(i))
+            op.binary_var(name=f"x{i}")
         # Linear constraints
         linear_constraint = {"x0": 1, "x1": 1}
         op.linear_constraint(linear_constraint, Constraint.Sense.EQ, 1, "x0x1")
@@ -263,7 +257,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test continuous mode of InequalityToEqualityConverter()"""
         op = QuadraticProgram()
         for i in range(3):
-            op.binary_var(name="x{}".format(i))
+            op.binary_var(name=f"x{i}")
         # Linear constraints
         linear_constraint = {"x0": 1, "x1": 1}
         op.linear_constraint(linear_constraint, Constraint.Sense.EQ, 1, "x0x1")
@@ -280,7 +274,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test auto mode of InequalityToEqualityConverter()"""
         op = QuadraticProgram()
         for i in range(3):
-            op.binary_var(name="x{}".format(i))
+            op.binary_var(name=f"x{i}")
         # Linear constraints
         linear_constraint = {"x0": 1, "x1": 1}
         op.linear_constraint(linear_constraint, Constraint.Sense.EQ, 1, "x0x1")
@@ -297,7 +291,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test PenalizeLinearEqualityConstraints with senses"""
         op = QuadraticProgram()
         for i in range(3):
-            op.binary_var(name="x{}".format(i))
+            op.binary_var(name=f"x{i}")
         # Linear constraints
         linear_constraint = {"x0": 1, "x1": 1}
         op.linear_constraint(linear_constraint, Constraint.Sense.EQ, 1, "x0x1")
@@ -314,7 +308,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test PenalizeLinearEqualityConstraints with binary variables"""
         op = QuadraticProgram()
         for i in range(3):
-            op.binary_var(name="x{}".format(i))
+            op.binary_var(name=f"x{i}")
         # Linear constraints
         linear_constraint = {"x0": 1, "x1": 1}
         op.linear_constraint(linear_constraint, Constraint.Sense.EQ, 1, "x0x1")
@@ -334,7 +328,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test PenalizeLinearEqualityConstraints with integer variables"""
         op = QuadraticProgram()
         for i in range(3):
-            op.integer_var(name="x{}".format(i), lowerbound=-3, upperbound=3)
+            op.integer_var(name=f"x{i}", lowerbound=-3, upperbound=3)
         # Linear constraints
         linear_constraint = {"x0": 1, "x1": 1}
         op.linear_constraint(linear_constraint, Constraint.Sense.EQ, 1, "x0x1")
@@ -355,7 +349,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test integer to binary"""
         op = QuadraticProgram()
         for i in range(0, 2):
-            op.binary_var(name="x{}".format(i))
+            op.binary_var(name=f"x{i}")
         op.integer_var(name="x2", lowerbound=0, upperbound=5)
         linear = {}
         for i, x in enumerate(op.variables):
@@ -375,7 +369,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test binary to integer"""
         op = QuadraticProgram()
         for i in range(0, 2):
-            op.binary_var(name="x{}".format(i))
+            op.binary_var(name=f"x{i}")
         op.integer_var(name="x2", lowerbound=0, upperbound=5)
         linear = {"x0": 1, "x1": 2, "x2": 1}
         op.maximize(0, linear, {})
@@ -392,7 +386,7 @@ class TestConverters(QiskitOptimizationTestCase):
         """Test optimization problem to operators"""
         op = QuadraticProgram()
         for i in range(4):
-            op.binary_var(name="x{}".format(i))
+            op.binary_var(name=f"x{i}")
         linear = {}
         for x in op.variables:
             linear[x.name] = 1
@@ -474,7 +468,7 @@ class TestConverters(QiskitOptimizationTestCase):
             quadratic.objective.quadratic.coefficients.toarray(), quadratic_matrix
         )
 
-    @requires_extra_library
+    @unittest.skipIf(not _optionals.HAS_CPLEX, "CPLEX not available.")
     def test_continuous_variable_decode(self):
         """Test decode func of IntegerToBinaryConverter for continuous variables"""
         mdl = Model("test_continuous_varable_decode")
