@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -36,7 +36,7 @@ class TestLinearExpression(QiskitOptimizationTestCase):
         coefficients_array = np.array(coefficients_list)
         coefficients_dok = dok_matrix([coefficients_list])
         coefficients_dict_int = {i: i for i in range(1, 5)}
-        coefficients_dict_str = {"x{}".format(i): i for i in range(1, 5)}
+        coefficients_dict_str = {f"x{i}": i for i in range(1, 5)}
 
         for coeffs in [
             coefficients_list,
@@ -77,7 +77,7 @@ class TestLinearExpression(QiskitOptimizationTestCase):
         coefficients_array = np.array(coefficients_list)
         coefficients_dok = dok_matrix([coefficients_list])
         coefficients_dict_int = {i: i for i in range(1, 5)}
-        coefficients_dict_str = {"x{}".format(i): i for i in range(1, 5)}
+        coefficients_dict_str = {f"x{i}": i for i in range(1, 5)}
 
         for coeffs in [
             coefficients_list,
@@ -104,7 +104,7 @@ class TestLinearExpression(QiskitOptimizationTestCase):
         values_list = list(range(len(x)))
         values_array = np.array(values_list)
         values_dict_int = {i: i for i in range(len(x))}
-        values_dict_str = {"x{}".format(i): i for i in range(len(x))}
+        values_dict_str = {f"x{i}": i for i in range(len(x))}
 
         for values in [values_list, values_array, values_dict_int, values_dict_str]:
             self.assertEqual(linear.evaluate(values), 30)
@@ -121,7 +121,7 @@ class TestLinearExpression(QiskitOptimizationTestCase):
         values_list = list(range(len(x)))
         values_array = np.array(values_list)
         values_dict_int = {i: i for i in range(len(x))}
-        values_dict_str = {"x{}".format(i): i for i in range(len(x))}
+        values_dict_str = {f"x{i}": i for i in range(len(x))}
 
         for values in [values_list, values_array, values_dict_int, values_dict_str]:
             np.testing.assert_almost_equal(linear.evaluate_gradient(values), coefficients_list)
@@ -173,6 +173,31 @@ class TestLinearExpression(QiskitOptimizationTestCase):
             coefficients_list = list(range(3))
             _ = LinearExpression(quadratic_program, coefficients_list).bounds
 
+    def test_str_repr(self):
+        """Test str and repr"""
+        with self.subTest("5 variables"):
+            n = 5
+            quadratic_program = QuadraticProgram()
+            quadratic_program.binary_var_list(n)  # x0,...,x4
+            expr = LinearExpression(quadratic_program, [float(e) for e in range(n)])
+            self.assertEqual(str(expr), "x1 + 2*x2 + 3*x3 + 4*x4")
+            self.assertEqual(repr(expr), "<LinearExpression: x1 + 2*x2 + 3*x3 + 4*x4>")
+
+        with self.subTest("50 variables"):
+            # pylint: disable=cyclic-import
+            from qiskit_optimization.translators.prettyprint import DEFAULT_TRUNCATE
+
+            n = 50
+            quadratic_program = QuadraticProgram()
+            quadratic_program.binary_var_list(n)  # x0,...,x49
+            expr = LinearExpression(quadratic_program, [float(e) for e in range(n)])
+
+            expected = " ".join(
+                ["x1"] + sorted([f"+ {i}*x{i}" for i in range(2, n)], key=lambda e: e.split(" ")[1])
+            )
+            self.assertEqual(str(expr), expected)
+            self.assertEqual(repr(expr), f"<LinearExpression: {expected[:DEFAULT_TRUNCATE]}...>")
+
 
 if __name__ == "__main__":
     unittest.main()
