@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -39,9 +39,7 @@ class TestQuadraticExpression(QiskitOptimizationTestCase):
         coefficients_array = np.array(coefficients_list)
         coefficients_dok = dok_matrix(coefficients_list)
         coefficients_dict_int = {(i, j): v for (i, j), v in coefficients_dok.items()}
-        coefficients_dict_str = {
-            ("x{}".format(i), "x{}".format(j)): v for (i, j), v in coefficients_dok.items()
-        }
+        coefficients_dict_str = {(f"x{i}", f"x{j}"): v for (i, j), v in coefficients_dok.items()}
 
         for coeffs in [
             coefficients_list,
@@ -69,11 +67,11 @@ class TestQuadraticExpression(QiskitOptimizationTestCase):
                 coefficients[min(i, j)][max(i, j)] += i * j
         quadratic = QuadraticExpression(quadratic_program, coefficients)
         for i, j_v in enumerate(coefficients):
-            for j, _ in enumerate(j_v):
+            for j, j_v_j in enumerate(j_v):
                 if i == j:
-                    self.assertEqual(quadratic[i, j], coefficients[i][j])
+                    self.assertEqual(quadratic[i, j], j_v_j)
                 else:
-                    self.assertEqual(quadratic[i, j], coefficients[i][j] + coefficients[j][i])
+                    self.assertEqual(quadratic[i, j], j_v_j + coefficients[j][i])
 
     def test_setters(self):
         """test setters."""
@@ -93,9 +91,7 @@ class TestQuadraticExpression(QiskitOptimizationTestCase):
         coefficients_array = np.array(coefficients_list)
         coefficients_dok = dok_matrix(coefficients_list)
         coefficients_dict_int = {(i, j): v for (i, j), v in coefficients_dok.items()}
-        coefficients_dict_str = {
-            ("x{}".format(i), "x{}".format(j)): v for (i, j), v in coefficients_dok.items()
-        }
+        coefficients_dict_str = {(f"x{i}", f"x{j}"): v for (i, j), v in coefficients_dok.items()}
 
         for coeffs in [
             coefficients_list,
@@ -125,7 +121,7 @@ class TestQuadraticExpression(QiskitOptimizationTestCase):
         values_list = list(range(len(x)))
         values_array = np.array(values_list)
         values_dict_int = {i: i for i in range(len(x))}
-        values_dict_str = {"x{}".format(i): i for i in range(len(x))}
+        values_dict_str = {f"x{i}": i for i in range(len(x))}
 
         for values in [values_list, values_array, values_dict_int, values_dict_str]:
             self.assertEqual(quadratic.evaluate(values), 900)
@@ -145,7 +141,7 @@ class TestQuadraticExpression(QiskitOptimizationTestCase):
         values_list = list(range(len(x)))
         values_array = np.array(values_list)
         values_dict_int = {i: i for i in range(len(x))}
-        values_dict_str = {"x{}".format(i): i for i in range(len(x))}
+        values_dict_str = {f"x{i}": i for i in range(len(x))}
 
         grad_values = [0.0, 60.0, 120.0, 180.0, 240.0]
         for values in [values_list, values_array, values_dict_int, values_dict_str]:
@@ -236,6 +232,47 @@ class TestQuadraticExpression(QiskitOptimizationTestCase):
             q_p.continuous_var(-1, INFINITY, "z")
             _ = QuadraticExpression(q_p, {("x", "y"): 1, ("y", "z"): 2, ("z", "z"): 3}).bounds
 
+    def test_str_repr(self):
+        """Test str and repr"""
+        with self.subTest("5 variables"):
+            n = 5
+            q_p = QuadraticProgram()
+            q_p.binary_var_list(n)  # x0,...,x4
+            expr = QuadraticExpression(q_p, {(i, i): float(i) for i in range(n)})
+            self.assertEqual(str(expr), "x1^2 + 2*x2^2 + 3*x3^2 + 4*x4^2")
+            self.assertEqual(repr(expr), "<QuadraticExpression: x1^2 + 2*x2^2 + 3*x3^2 + 4*x4^2>")
+
+            expr = QuadraticExpression(q_p, {(i, (i + 1) % n): float(i) for i in range(n)})
+            self.assertEqual(str(expr), "4*x0*x4 + x1*x2 + 2*x2*x3 + 3*x3*x4")
+            self.assertEqual(
+                repr(expr), "<QuadraticExpression: 4*x0*x4 + x1*x2 + 2*x2*x3 + 3*x3*x4>"
+            )
+
+        with self.subTest("50 variables"):
+            # pylint: disable=cyclic-import
+            from qiskit_optimization.translators.prettyprint import DEFAULT_TRUNCATE
+
+            n = 50
+            q_p = QuadraticProgram()
+            q_p.binary_var_list(n)  # x0,...,x49
+            expr = QuadraticExpression(q_p, {(i, i): float(i) for i in range(n)})
+            expected = " ".join(
+                ["x1^2"]
+                + sorted([f"+ {i}*x{i}^2" for i in range(2, n)], key=lambda e: e.split(" ")[1])
+            )
+            self.assertEqual(str(expr), expected)
+            self.assertEqual(repr(expr), f"<QuadraticExpression: {expected[:DEFAULT_TRUNCATE]}...>")
+
+            expr = QuadraticExpression(q_p, {(i, (i + 1) % n): float(i) for i in range(n)})
+            expected = " ".join(
+                [f"{n-1}*x0*x{n-1}", "+ x1*x2"]
+                + sorted(
+                    [f"+ {i}*x{i}*x{i + 1}" for i in range(2, n - 1)], key=lambda e: e.split(" ")[1]
+                )
+            )
+            self.assertEqual(str(expr), expected)
+            self.assertEqual(repr(expr), f"<QuadraticExpression: {expected[:DEFAULT_TRUNCATE]}...>")
+
 
 if __name__ == "__main__":
     unittest.main()
